@@ -1,6 +1,5 @@
-import numpy as np
 from .kd_transform import KDTransform
-from torchvision.transforms import Compose
+from .kd_stochastic_transform import KDStochasticTransform
 
 class KDComposeTransform(KDTransform):
     def __init__(self, transforms):
@@ -19,4 +18,4 @@ class KDComposeTransform(KDTransform):
                 x = t(x, ctx)
             else:
                 x = t(x)
-        return x
\ No newline at end of file
+        return x
